@@ -233,7 +233,7 @@ void MainWindow::about()
     QMessageBox msg;
     msg.setIconPixmap(QPixmap (":images/Tomamp.png"));
     msg.setModal(true);
-    msg.setWindowTitle(tr ("About TomAmp v0.4.3"));
+    msg.setWindowTitle(tr ("About TomAmp v0.4.4.1"));
     msg.setText(tr("TomAmp is a simple playlist-based music player.\n\n"
                 "(c) 2010 Tamas Marki <tmarki@gmail.com>\n"
                 "Please send comments and bug reports to the above e-mail address.\n\n"
@@ -655,6 +655,7 @@ void MainWindow::setupUi()
 
     addMenu = new QMenu (this);
     
+    mwa->setupContextAndAddMenu(contextMenu, addMenu, this);    
 
     timeLcd = new QLCDNumber;
 
@@ -748,10 +749,13 @@ void MainWindow::enqueueSelected()
 
 void MainWindow::contextMenuEvent (QContextMenuEvent*e)
 {
+    qDebug () << "0: " << childAt (e->pos());
     if (!childAt (e->pos()))
         return;
+    qDebug () << "1: " << childAt (e->pos())->parentWidget();
     if (childAt (e->pos())->parentWidget() != musicTable)
         return;
+    qDebug () << "2";
     contextMenu->popup(e->globalPos());
 }
 
@@ -1056,21 +1060,25 @@ void MainWindow::showOptions ()
 
 void MainWindow::showEqualizer ()
 {
-    QList<int> vals;
-    QStringList labels;
     if (eqEffect)
     {
+        QList<int> vals;
+        QStringList labels;
         foreach(Phonon::EffectParameter ep, eqEffect->parameters())
         {
             vals.push_back(int (eqEffect->parameterValue(ep).toDouble()));
             labels.push_back(ep.name());
         }
+        EqualizerDialog* dlg = new EqualizerDialog (this, vals, labels, settings.value("equalizer", false).toBool ());
+        connect (dlg, SIGNAL(equalizerChanged(int,int)), this, SLOT(equalizerChanged(int,int)));
+        connect (dlg, SIGNAL(toggleEqualizer(bool)), this, SLOT(toggleEqualizer(bool)));
+        dlg->exec();
+        delete dlg;
+    }
+    else
+    {
+        QMessageBox::warning(this, tr ("Equalizer"), tr ("The required equalizer component was not found on your system, sorry!"));
     }
-    EqualizerDialog* dlg = new EqualizerDialog (this, vals, labels, settings.value("equalizer", false).toBool ());
-    connect (dlg, SIGNAL(equalizerChanged(int,int)), this, SLOT(equalizerChanged(int,int)));
-    connect (dlg, SIGNAL(toggleEqualizer(bool)), this, SLOT(toggleEqualizer(bool)));
-    dlg->exec();
-    delete dlg;
 }
 
 void MainWindow::toggleEqualizer(bool val)
@@ -1117,9 +1125,13 @@ void MainWindow::equalizerChanged (int ind, int val)
     if (eqEffect)
     {
         double dval = (double)val;
-        eqEffect->setParameterValue(eqEffect->parameters()[ind], dval);
-        QString valName = QString ("eq_%1").arg(ind);
-        settings.setValue(valName, dval);
+        QList<Phonon::EffectParameter> pars = eqEffect->parameters();
+        if (pars.size() > ind)
+        {
+            eqEffect->setParameterValue(pars[ind], dval);
+            QString valName = QString ("eq_%1").arg(ind);
+            settings.setValue(valName, dval);
+        }
     }
 }
 
