@@ -104,6 +104,7 @@ void PlaylistManager::addStringList(const QStringList& list, const QStringList&
                                         || (string.toLower().endsWith("m3u")))))
             {
                 downloadmanager->get(QNetworkRequest(QUrl(string)));
+                qDebug () << "Download " << string;
             }
             else
             {
@@ -138,6 +139,7 @@ void PlaylistManager::playlistDownloadFinished(QNetworkReply* rep)
     QString filename = tmp.fileName();
     int index = items.size();
     QString ext = rep->url().toString().right(4).toLower();
+    qDebug () << "Downloaded " << rep->url ();
     if (ext == ".m3u")
         appendPlaylist(filename);
     else if (ext == ".pls")
@@ -146,6 +148,7 @@ void PlaylistManager::playlistDownloadFinished(QNetworkReply* rep)
         appendPlaylistCUE(filename);
     if (items.size () > index)
     {
+        qDebug () << "Added " << items.size() - index << " items";
         metaInformationResolver->setCurrentSource(items.at(index).source);
         lastMetaRead = index;
         emit playlistChanged (index);
@@ -322,12 +325,16 @@ void PlaylistManager::appendPlaylist(const QString& filename)
             continue;
         }
         l = l.replace("\r", "");
-        QString fname = dir + QDir::separator() + l;
+        QString fname = l;
+        if (!l.startsWith("http"))
+            fname = dir + QDir::separator() + l;
+        qDebug () << "Playlist item " << fname;
         if (QFile::exists(l))
             fname = l;
-        if (QFile::exists(fname))
+        if (QFile::exists(fname) || fname.startsWith("http"))
             items.append(PlaylistItem (fname));
-    }
+        else
+            qDebug () << "Not existing, not added";    }
 }
 
 void PlaylistManager::appendPlaylistPLS(const QString& filename)
@@ -357,10 +364,13 @@ void PlaylistManager::appendPlaylistPLS(const QString& filename)
                 continue;
             tokens[0] = tokens[0].mid (4);
             filemap.insert(tokens[0].toInt (), items.size ());
-            QString fname = dir + QDir::separator() + tokens[1];
+            QString fname = l;
+            if (!l.startsWith("http"))
+                fname = dir + QDir::separator() + l;
+            qDebug () << "Playlist item " << fname;
             if (QFile::exists(l))
                 fname = tokens[1];
-            if (QFile::exists(fname))
+            if (QFile::exists(fname) || fname.startsWith("http"))
                 items.append(PlaylistItem (fname));
         }
         else if (l.trimmed().toLower().left(5) == "title")
